---
title: '[2024년04월]서비스 이용약관 개정 변경안내 '
category: 공지사항
tags:
  - 공지사항
datetime: 2024-03-31T15:00:00.000Z
---

안녕하세요\~! 포트원 입니다.

항상 포트원을 이용해주시는 고객 여러분께 진심으로 감사드립니다.\
2024년 04월 15일 아래와 같이 서비스 이용약관이 변경됨을 사전 안내 드립니다.

- 공고일 : 2024.04.08(월)
- 시행일 : 2024.04.15(월)

<Highlight text="변경내용" />

<Accordion title="▶ 제 2조 용어의 정의" content="<>
  ![](/uploads/포트원소식/이용약관.png)
</>" />

<Accordion title="▶ 제 3조 서비스의 내용" content="<>
  ![](/uploads/포트원소식/이용약관_1.png)
</>" />

<Accordion title="▶ 제 7조 서비스의 제공" content="<>
  ![](/uploads/포트원소식/이용약관_2.png)
</>" />

<Accordion title="▶ 제 8조 이용요금" content="<>
  ![](/uploads/포트원소식/이용약관_3.png)
</>" />

<Accordion title="▶ 제 13조 개인정보 위수탁에 관한 사항" content="<>
  ![](/uploads/포트원소식/이용약관_4.png)
</>" />
